(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)



(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21802,        867]*)
(*NotebookOutlinePosition[     22433,        889]*)
(*  CellTagsIndexPosition[     22389,        885]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  ScriptMinSize->12,
  FontSize->16],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellBracketOptions->{"Margins"->{1, 1},
  "Widths"->{0, 5}},
  ScriptMinSize->8,
  FontSize->11],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->5,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "Slide"],
  PageWidth->PaperWidth,
  ScriptMinSize->12,
  FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  CellFrameLabelMargins->6,
  LimitsPositioningTokens->{},
  StyleMenuListing->None],

Cell[StyleData["Notebook", "Slide"],
  PageHeaders->{{None, None, None}, {None, None, None}},
  PageHeaderLines->{False, False},
  CellFrameLabelMargins->6,
  LimitsPositioningTokens->{},
  StyleMenuListing->None]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  ShowCellBracket->False,
  CellMargins->{{0, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->RGBColor[0.164706, 0.0392157, 0.768627],
  Background->GrayLevel[0.900008]],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{0, 10}, {20, 40}},
  TextAlignment->Center,
  LineSpacing->{1, 0},
  FontSize->44],

Cell[StyleData["Title", "Condensed"],
  CellMargins->{{0, 10}, {4, 8}},
  TextAlignment->Center,
  FontSize->20],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{0, 10}, {12, 30}},
  TextAlignment->Center,
  FontSize->24]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->24],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{24, 10}, {20, 20}},
  TextAlignment->Center,
  LineSpacing->{1, 0},
  FontSize->36],

Cell[StyleData["Subtitle", "Condensed"],
  CellMargins->{{8, 10}, {4, 4}},
  TextAlignment->Center,
  FontSize->14],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  TextAlignment->Center,
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  TextAlignment->Center,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{24, 10}, {20, 20}},
  TextAlignment->Center,
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellMargins->{{8, 10}, {8, 8}},
  TextAlignment->Center,
  FontSize->12],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  TextAlignment->Center,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{25, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{40, 10}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Section", "Condensed"],
  CellMargins->{{18, Inherited}, {6, 12}},
  FontSize->12],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{13, 0}, {7, 22}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  StyleMenuListing->None,
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{36, 10}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->22],

Cell[StyleData["Subsection", "Condensed"],
  CellMargins->{{16, Inherited}, {6, 12}},
  FontSize->12],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 22}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{22, Inherited}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{34, 10}, {11, 26}},
  LineSpacing->{1, 0},
  FontSize->18],

Cell[StyleData["Subsubsection", "Condensed"],
  CellMargins->{{17, Inherited}, {6, 12}},
  FontSize->10],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{9, 0}, {7, 14}},
  FontSize->11]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontColor->GrayLevel[0]],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Text", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  CounterIncrements->"SmallText",
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{24, 10}, {8, 8}},
  LineSpacing->{1, 5},
  FontSize->12],

Cell[StyleData["SmallText", "Condensed"],
  CellMargins->{{8, 10}, {5, 5}},
  LineSpacing->{1, 2},
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Proof Cells", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ProofText"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  ParagraphIndent->0,
  CounterIncrements->"Text",
  FontColor->GrayLevel[0]],

Cell[StyleData["ProofText", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["ProofText", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["ProofText", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}],

Cell[StyleData["ProofText", "Slide"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Label"],
  CellMargins->{{20, 30}, {7, 7}},
  LineSpacing->{1, 3},
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Label", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Label", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["Label", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}],

Cell[StyleData["Label", "Slide"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Conclusion"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Conclusion", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Conclusion", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["Conclusion", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}],

Cell[StyleData["Conclusion", "Slide"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Assumption"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  FontColor->RGBColor[1, 0, 1]],

Cell[StyleData["Assumption", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Assumption", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["Assumption", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}],

Cell[StyleData["Assumption", "Slide"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Expression"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3}],

Cell[StyleData["Expression", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Expression", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["Expression", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}],

Cell[StyleData["Expression", "Slide"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Indent"],
  CellSize->{25, Inherited}],

Cell[StyleData["Indent", "Presentation"],
  CellSize->{30, Inherited}],

Cell[StyleData["Indent", "Condensed"],
  CellSize->{15, Inherited}],

Cell[StyleData["Indent", "Printout"],
  CellSize->{15, Inherited}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Blank"],
  CellSize->{15, Inherited}],

Cell[StyleData["Blank", "Presentation"],
  CellSize->{20, Inherited}],

Cell[StyleData["Blank", "Condensed"],
  CellSize->{10, Inherited}],

Cell[StyleData["Blank", "Printout"],
  CellSize->{10, Inherited}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{72, Inherited}, {8, 10}},
  LineSpacing->{1, 0}],

Cell[StyleData["Input", "Condensed"],
  CellMargins->{{40, 10}, {2, 3}}],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Open  ]],

Cell[StyleData["InputOnly"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output",
  StyleMenuListing->None],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{72, Inherited}, {10, 8}},
  LineSpacing->{1, 0}],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{41, Inherited}, {3, 2}}],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0}],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}}],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Presentation"],
  ImageMargins->{{62, Inherited}, {Inherited, 0}}],

Cell[StyleData["Graphics", "Condensed"],
  ImageMargins->{{38, Inherited}, {Inherited, 0}},
  Magnification->0.6],

Cell[StyleData["Graphics", "Printout"],
  ImageMargins->{{30, Inherited}, {Inherited, 0}},
  FontSize->9,
  Magnification->0.8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->12],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->9],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  ScriptLevel->1,
  SingleLetterItalics->True,
  StyleMenuListing->None],

Cell[StyleData["InlineFormula", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["InlineFormula", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["InlineFormula", "Printout"],
  CellMargins->{{2, 0}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{42, Inherited}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  ScriptLevel->0,
  SingleLetterItalics->True,
  StyleMenuListing->None,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Presentation"],
  LineSpacing->{1, 5}],

Cell[StyleData["DisplayFormula", "Condensed"],
  LineSpacing->{1, 1}],

Cell[StyleData["DisplayFormula", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Presentation"]],

Cell[StyleData["Hyperlink", "Condensed"]],

Cell[StyleData["Hyperlink", "Printout"],
  FontVariations->{"Underline"->False}]
}, Open  ]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{0.6, 1},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{730, 678},
WindowMargins->{{Automatic, 211}, {45, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 37, 0, 64, "Subtitle"],
Cell[1767, 54, 193, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[1985, 62, 42, 0, 60, "Section"],
Cell[2030, 64, 77, 2, 38, 31, 0, "StyleData", "All", "Working"],
Cell[2110, 68, 99, 3, 41, 36, 0, "StyleData", "All", "Presentation"],
Cell[2212, 73, 158, 5, 35, 33, 0, "StyleData", "All", "Condensed"],
Cell[2373, 80, 140, 4, 32, 32, 0, "StyleData", "All", "Printout"],
Cell[2516, 86, 91, 3, 50, 29, 0, "StyleData", "All", "Slide"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2644, 94, 35, 0, 60, "Section"],
Cell[2682, 96, 101, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[2808, 103, 457, 12, 38, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None],
Cell[3268, 117, 213, 5, 38, 36, 0, "StyleData", "Notebook", "Slide",
  StyleMenuListing->None]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3530, 128, 38, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[3593, 132, 534, 15, 70, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  StyleMenuListing->None],
Cell[4130, 149, 140, 4, 70, 40, 0, "StyleData", "Title", "Presentation"],
Cell[4273, 155, 112, 3, 70, 37, 0, "StyleData", "Title", "Condensed"],
Cell[4388, 160, 113, 3, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4538, 168, 366, 10, 70, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  StyleMenuListing->None],
Cell[4907, 180, 144, 4, 70, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[5054, 186, 115, 3, 70, 40, 0, "StyleData", "Subtitle", "Condensed"],
Cell[5172, 191, 115, 3, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5324, 199, 368, 10, 70, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  StyleMenuListing->None],
Cell[5695, 211, 147, 4, 70, 46, 0, "StyleData", "Subsubtitle", \
"Presentation"],
Cell[5845, 217, 118, 3, 70, 43, 0, "StyleData", "Subsubtitle", "Condensed"],
Cell[5966, 222, 118, 3, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6121, 230, 362, 10, 70, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[6486, 242, 118, 3, 70, 42, 0, "StyleData", "Section", "Presentation"],
Cell[6607, 247, 98, 2, 70, 39, 0, "StyleData", "Section", "Condensed"],
Cell[6708, 251, 89, 2, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6834, 258, 327, 9, 70, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[7164, 269, 121, 3, 70, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[7288, 274, 101, 2, 70, 42, 0, "StyleData", "Subsection", "Condensed"],
Cell[7392, 278, 91, 2, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7520, 285, 271, 7, 70, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection",
  StyleMenuListing->None],
Cell[7794, 294, 124, 3, 70, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[7921, 299, 104, 2, 70, 45, 0, "StyleData", "Subsubsection", \
"Condensed"],
Cell[8028, 303, 94, 2, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8171, 311, 39, 0, 40, "Section"],

Cell[CellGroupData[{
Cell[8235, 315, 137, 4, 70, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[8375, 321, 99, 2, 70, 39, 0, "StyleData", "Text", "Presentation"],
Cell[8477, 325, 93, 2, 70, 36, 0, "StyleData", "Text", "Condensed"],
Cell[8573, 329, 68, 1, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[8678, 335, 162, 5, 70, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[8843, 342, 118, 3, 70, 44, 0, "StyleData", "SmallText", "Presentation"],
Cell[8964, 347, 113, 3, 70, 41, 0, "StyleData", "SmallText", "Condensed"],
Cell[9080, 352, 88, 2, 70, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9217, 360, 41, 0, 40, "Section"],

Cell[CellGroupData[{
Cell[9283, 364, 164, 5, 44, 28, 0, "StyleData", "ProofText", "All",
  CounterIncrements->"Text"],
Cell[9450, 371, 104, 2, 50, 44, 0, "StyleData", "ProofText", "Presentation"],
Cell[9557, 375, 98, 2, 42, 41, 0, "StyleData", "ProofText", "Condensed"],
Cell[9658, 379, 73, 1, 42, 40, 0, "StyleData", "ProofText", "Printout"],
Cell[9734, 382, 70, 1, 42, 37, 0, "StyleData", "ProofText", "Slide"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9841, 388, 114, 3, 44, 24, 0, "StyleData", "Label", "All"],
Cell[9958, 393, 100, 2, 50, 40, 0, "StyleData", "Label", "Presentation"],
Cell[10061, 397, 94, 2, 42, 37, 0, "StyleData", "Label", "Condensed"],
Cell[10158, 401, 69, 1, 42, 36, 0, "StyleData", "Label", "Printout"],
Cell[10230, 404, 66, 1, 42, 33, 0, "StyleData", "Label", "Slide"]
}, Closed]],

Cell[CellGroupData[{
Cell[10333, 410, 119, 3, 41, 29, 0, "StyleData", "Conclusion", "All"],
Cell[10455, 415, 105, 2, 50, 45, 0, "StyleData", "Conclusion", \
"Presentation"],
Cell[10563, 419, 99, 2, 42, 42, 0, "StyleData", "Conclusion", "Condensed"],
Cell[10665, 423, 74, 1, 42, 41, 0, "StyleData", "Conclusion", "Printout"],
Cell[10742, 426, 71, 1, 42, 38, 0, "StyleData", "Conclusion", "Slide"]
}, Closed]],

Cell[CellGroupData[{
Cell[10850, 432, 119, 3, 41, 29, 0, "StyleData", "Assumption", "All"],
Cell[10972, 437, 105, 2, 50, 45, 0, "StyleData", "Assumption", \
"Presentation"],
Cell[11080, 441, 99, 2, 42, 42, 0, "StyleData", "Assumption", "Condensed"],
Cell[11182, 445, 74, 1, 42, 41, 0, "StyleData", "Assumption", "Printout"],
Cell[11259, 448, 71, 1, 42, 38, 0, "StyleData", "Assumption", "Slide"]
}, Closed]],

Cell[CellGroupData[{
Cell[11367, 454, 87, 2, 41, 29, 0, "StyleData", "Expression", "All"],
Cell[11457, 458, 105, 2, 50, 45, 0, "StyleData", "Expression", \
"Presentation"],
Cell[11565, 462, 99, 2, 42, 42, 0, "StyleData", "Expression", "Condensed"],
Cell[11667, 466, 74, 1, 42, 41, 0, "StyleData", "Expression", "Printout"],
Cell[11744, 469, 71, 1, 42, 38, 0, "StyleData", "Expression", "Slide"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11852, 475, 54, 1, 38, 25, 0, "StyleData", "Indent", "All"],
Cell[11909, 478, 70, 1, 70, 41, 0, "StyleData", "Indent", "Presentation"],
Cell[11982, 481, 67, 1, 70, 38, 0, "StyleData", "Indent", "Condensed"],
Cell[12052, 484, 66, 1, 70, 37, 0, "StyleData", "Indent", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12155, 490, 53, 1, 38, 24, 0, "StyleData", "Blank", "All"],
Cell[12211, 493, 69, 1, 70, 40, 0, "StyleData", "Blank", "Presentation"],
Cell[12283, 496, 66, 1, 70, 37, 0, "StyleData", "Blank", "Condensed"],
Cell[12352, 499, 65, 1, 70, 36, 0, "StyleData", "Blank", "Printout"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12466, 506, 42, 0, 60, "Section"],
Cell[12511, 508, 364, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[12900, 518, 460, 14, 70, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],
Cell[13363, 534, 106, 2, 70, 40, 0, "StyleData", "Input", "Presentation"],
Cell[13472, 538, 72, 1, 70, 37, 0, "StyleData", "Input", "Condensed"],
Cell[13547, 541, 85, 2, 70, 36, 0, "StyleData", "Input", "Printout"]
}, Open  ]],
Cell[13647, 546, 309, 10, 70, 28, 0, "StyleData", "InputOnly", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[13981, 560, 480, 14, 70, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output",
  StyleMenuListing->None],
Cell[14464, 576, 107, 2, 70, 41, 0, "StyleData", "Output", "Presentation"],
Cell[14574, 580, 80, 1, 70, 38, 0, "StyleData", "Output", "Condensed"],
Cell[14657, 583, 86, 2, 70, 37, 0, "StyleData", "Output", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[14780, 590, 501, 14, 70, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[15284, 606, 123, 2, 70, 42, 0, "StyleData", "Message", "Presentation"],
Cell[15410, 610, 97, 1, 70, 39, 0, "StyleData", "Message", "Condensed"],
Cell[15510, 613, 138, 3, 70, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15685, 621, 465, 13, 70, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[16153, 636, 121, 2, 70, 40, 0, "StyleData", "Print", "Presentation"],
Cell[16277, 640, 95, 1, 70, 37, 0, "StyleData", "Print", "Condensed"],
Cell[16375, 643, 109, 2, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16521, 650, 439, 12, 70, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[16963, 664, 94, 1, 70, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[17060, 667, 113, 2, 70, 40, 0, "StyleData", "Graphics", "Condensed"],
Cell[17176, 671, 127, 3, 70, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17340, 679, 128, 4, 70, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[17471, 685, 60, 1, 70, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[17534, 688, 56, 1, 70, 41, 0, "StyleData", "CellLabel", "Condensed"],
Cell[17593, 691, 130, 4, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17772, 701, 43, 0, 40, "Section"],

Cell[CellGroupData[{
Cell[17840, 705, 172, 5, 70, 32, 0, "StyleData", "InlineFormula", "All",
  StyleMenuListing->None],
Cell[18015, 712, 108, 2, 70, 48, 0, "StyleData", "InlineFormula", \
"Presentation"],
Cell[18126, 716, 102, 2, 70, 45, 0, "StyleData", "InlineFormula", \
"Condensed"],
Cell[18231, 720, 77, 1, 70, 44, 0, "StyleData", "InlineFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18345, 726, 298, 7, 70, 33, 0, "StyleData", "DisplayFormula", "All",
  StyleMenuListing->None],
Cell[18646, 735, 72, 1, 70, 49, 0, "StyleData", "DisplayFormula", \
"Presentation"],
Cell[18721, 738, 69, 1, 70, 46, 0, "StyleData", "DisplayFormula", \
"Condensed"],
Cell[18793, 741, 45, 0, 70, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18887, 747, 49, 0, 40, "Section"],
Cell[18939, 749, 123, 4, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[19065, 755, 122, 4, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[19190, 761, 127, 4, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[19354, 770, 35, 0, 40, "Section"],
Cell[19392, 772, 184, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[19601, 780, 302, 8, 38, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[19906, 790, 44, 0, 38, 44, 0, "StyleData", "Hyperlink", "Presentation"],
Cell[19953, 792, 41, 0, 38, 41, 0, "StyleData", "Hyperlink", "Condensed"],
Cell[19997, 794, 80, 1, 38, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Open  ]],
Cell[20092, 798, 104, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20233, 806, 36, 0, 60, "Section"],
Cell[20272, 808, 305, 5, 68, "Text"],
Cell[20580, 815, 314, 10, 37, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[20897, 827, 106, 3, 37, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[21006, 832, 151, 5, 37, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[21160, 839, 108, 3, 37, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[21271, 844, 179, 5, 70, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[21453, 851, 115, 3, 70, "Text"],
Cell[21571, 856, 96, 3, 70, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[21670, 861, 104, 2, 70, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

