(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4309,        134]*)
(*NotebookOutlinePosition[      4956,        157]*)
(*  CellTagsIndexPosition[      4912,        153]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Example: Square Root", "Title"],

Cell["\<\
This example shows the effect of restricting the number of \
inferences on the size of the proofs.\
\>", "Text"],

Cell["\<\
Most of the inference steps are similar to unit resolution: a \
ground unit formula is combined with a universal implication whose premise \
matches the ground unit. \
\>", "Text"],

Cell["\<\
Note: the proofs are linked to this notebook, and are presented \
using the style sheet \"TheoremaProof.nb\" (also present in this directory). \
If the style sheet is not selected automatically, then there will be a \
warning message and you must select the style sheet manually from the menu \
(Format \[Rule] StyleSheet \[Rule] Other ...).\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  ButtonBox["Version 0",
    ButtonData:>{"proof-sqrt2-version0-complete.nb", None},
    ButtonStyle->"Hyperlink"],
  ":  resolution: 600 formulae, 50 minutes"
}], "Subsubsection"],

Cell["\<\
In this version all possible inferences are performed (\"level \
saturation\"), until the empty clause (\"contradiction\") is obtained.\
\>", \
"Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  ButtonBox["Version 1",
    ButtonData:>{"proof-sqrt2-version1-complete.nb", None},
    ButtonStyle->"Hyperlink"],
  ":  resolution + propositional saturation: 350 formulae, 10 minutes"
}], "Subsubsection"],

Cell["\<\
In this version the \"level saturation\" strategy is applied first \
at the propositional level: we do not perform quantified inferences unless \
there are no more propositional inferences possible.\
\>", "Text"],

Cell[TextData[{
  ButtonBox["Version 1, simplified",
    ButtonData:>{"proof-sqrt2-version1-useful.nb", None},
    ButtonStyle->"Hyperlink"],
  ":  contains only the inferences which are necessary in order to complete \
the proof."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  ButtonBox["Version 2",
    ButtonData:>{"proof-sqrt2-version2-complete.nb", None},
    ButtonStyle->"Hyperlink"],
  ":  hyper-resolution: 50 formulae, 3 minutes"
}], "Subsubsection"],

Cell["\<\
In this version a quantified inference is performed only if each \
negative literal in the universal formula matches some ground unit formula. \
This is roughly equivalent to hyper-resolution. Moreover, when searching for \
possible inferences, the prover considers first those literals in the \
universal formula which are innermost -- which is similar to applying an \
order on the predicate symbols.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1016, 696},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 101, "Title"],
Cell[1816, 55, 122, 3, 32, "Text"],
Cell[1941, 60, 190, 4, 32, "Text"],
Cell[2134, 66, 365, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[2524, 76, 196, 5, 28, "Subsubsection"],
Cell[2723, 83, 161, 4, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2921, 92, 223, 5, 28, "Subsubsection"],
Cell[3147, 99, 222, 4, 50, "Text"],
Cell[3372, 105, 243, 6, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3652, 116, 200, 5, 28, "Subsubsection"],
Cell[3855, 123, 426, 7, 68, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

